<?php

return [
    'number.decimals_separator' => '.',
    'number.thousands_separator' => ',',
    'None' => 'Hiçbiri',
    'Edit' => 'Düzenle',
    'Remove' => 'Sil',
    'Yes' => 'Evet',
    'No' => 'Hayır',
    'cancel' => 'İptal',
    'or' => 'veya',
    'Yellow' => 'Sarı',
    'Blue' => 'Mavi',
    'Green' => 'Yeşil',
    'Purple' => 'Mor',
    'Red' => 'Kırmızı',
    'Orange' => 'Turuncu',
    'Grey' => 'Gri',
    'Brown' => 'K.rengi',
    'Deep Orange' => 'Kavuniçi',
    'Dark Grey' => 'Koyu Gri',
    'Pink' => 'Pembe',
    'Teal' => 'Turkuaz',
    'Cyan' => 'Cam Göbeği',
    'Lime' => 'Limoni',
    'Light Green' => 'Açık Yeşil',
    'Amber' => 'Koyu Sarı',
    'Save' => 'Kaydet',
    'Login' => 'Giriş',
    'Official website:' => 'Resmi internet sitesi:',
    'Unassigned' => 'Atanmamış',
    'View this task' => 'Bu görevi görüntüle',
    'Remove user' => 'Kullanıcıyı kaldır',
    'Do you really want to remove this user: "%s"?' => 'Bu kullanıcıyı gerçekten silmek istiyor musunuz: "%s"?',
    'All users' => 'Tüm kullanıcılar',
    'Username' => 'Kullanıcı adı',
    'Password' => 'Şifre',
    'Administrator' => 'Yönetici',
    'Sign in' => 'Giriş yap',
    'Users' => 'Kullanıcılar',
    'Forbidden' => 'Yasak',
    'Access Forbidden' => 'Erişim yasaklandı',
    'Edit user' => 'Kullanıcıyı düzenle',
    'Logout' => 'Çıkış yap',
    'Bad username or password' => 'Hatalı kullanıcı adı veya şifre',
    'Edit project' => 'Projeyi düzenle',
    'Name' => 'İsim',
    'Projects' => 'Projeler',
    'No project' => 'Proje yok',
    'Project' => 'Proje',
    'Status' => 'Durum',
    'Tasks' => 'Görevler',
    'Board' => 'Pano',
    'Actions' => 'İşlemler',
    'Inactive' => 'Aktif değil',
    'Active' => 'Aktif',
    'Unable to update this board.' => 'Bu pano güncellenemiyor.',
    'Disable' => 'Devre dışı bırak',
    'Enable' => 'Etkinleştir',
    'New project' => 'Yeni proje',
    'Do you really want to remove this project: "%s"?' => 'Bu projeyi gerçekten silmek istiyor musunuz: "%s"?',
    'Remove project' => 'Projeyi sil',
    'Edit the board for "%s"' => 'Panoyu "%s" için güncelle',
    'Add a new column' => 'Yeni sütun ekle',
    'Title' => 'Başlık',
    'Assigned to %s' => '%s kullanıcısına atanmış',
    'Remove a column' => 'Bir sütunu sil',
    'Unable to remove this column.' => 'Bu sütun silinemiyor.',
    'Do you really want to remove this column: "%s"?' => 'Bu sütunu gerçekten silmek istiyor musunuz: "%s"?',
    'Settings' => 'Ayarlar',
    'Application settings' => 'Uygulama ayarları',
    'Language' => 'Dil',
    'Webhook token:' => 'Web kancası anahtarı:',
    'API token:' => 'API anahtarı:',
    'Database size:' => 'Veritabanı boyutu:',
    'Download the database' => 'Veritabanını indir',
    'Optimize the database' => 'Veritabanını optimize et',
    '(VACUUM command)' => '(VACUUM komutu)',
    '(Gzip compressed Sqlite file)' => '(Gzip ile sıkıştırılmış Sqlite dosyası)',
    'Close a task' => 'Bir görevi kapat',
    'Column' => 'Sütun',
    'Color' => 'Renk',
    'Assignee' => 'Atanan',
    'Create another task' => 'Başka bir görev oluştur',
    'New task' => 'Yeni görev',
    'Open a task' => 'Bir görevi aç',
    'Do you really want to open this task: "%s"?' => 'Bu görevi gerçekten açmak istiyor musunuz: "%s"?',
    'Back to the board' => 'Panoya dön',
    'There is nobody assigned' => 'Kimse atanmamış',
    'Column on the board:' => 'Panodaki sütun:',
    'Close this task' => 'Görevi kapat',
    'Open this task' => 'Görevi aç',
    'There is no description.' => 'Açıklama yok.',
    'Add a new task' => 'Yeni görev ekle',
    'The username is required' => 'Kullanıcı adı gerekli',
    'The maximum length is %d characters' => 'Maksimum uzunluk %d karakterdir',
    'The minimum length is %d characters' => 'Minimum uzunluk %d karakterdir',
    'The password is required' => 'Şifre gerekli',
    'This value must be an integer' => 'Bu değer bir rakam olmak zorunda',
    'The username must be unique' => 'Kullanıcı adı daha önceden var',
    'The user id is required' => 'Kullanıcı kodu gerekli',
    'Passwords don\'t match' => 'Şifreler uyuşmuyor',
    'The confirmation is required' => 'Onay gerekli',
    'The project is required' => 'Proje gerekli',
    'The id is required' => 'Kod gerekli',
    'The project id is required' => 'Proje kodu gerekli',
    'The project name is required' => 'Proje adı gerekli',
    'The title is required' => 'Başlık gerekli',
    'Settings saved successfully.' => 'Ayarlar başarıyla kaydedildi.',
    'Unable to save your settings.' => 'Ayarlarınız kaydedilemedi.',
    'Database optimization done.' => 'Veritabanı optimizasyonu tamamlandı.',
    'Your project has been created successfully.' => 'Projeniz başarıyla oluşturuldu.',
    'Unable to create your project.' => 'Proje oluşturulamadı.',
    'Project updated successfully.' => 'Proje başarıyla güncellendi.',
    'Unable to update this project.' => 'Bu proje güncellenemedi.',
    'Unable to remove this project.' => 'Bu proje silinemedi.',
    'Project removed successfully.' => 'Proje başarıyla silindi.',
    'Project activated successfully.' => 'Proje başarıyla aktif edildi.',
    'Unable to activate this project.' => 'Bu proje aktif edilemedi.',
    'Project disabled successfully.' => 'Proje başarıyla devre dışı bırakıldı.',
    'Unable to disable this project.' => 'Bu proje devre dışı bırakılamadı.',
    'Unable to open this task.' => 'Bu görev açılamıyor.',
    'Task opened successfully.' => 'Görev başarıyla açıldı.',
    'Unable to close this task.' => 'Bu görev kapatılamıyor.',
    'Task closed successfully.' => 'Görev başarıyla kapatıldı.',
    'Unable to update your task.' => 'Görev güncellenemiyor.',
    'Task updated successfully.' => 'Görev başarıyla güncellendi.',
    'Unable to create your task.' => 'Görev oluşturulamadı.',
    'Task created successfully.' => 'Görev başarıyla oluşturuldu.',
    'User created successfully.' => 'Kullanıcı başarıyla oluşturuldu',
    'Unable to create your user.' => 'Kullanıcı oluşturulamadı.',
    'User updated successfully.' => 'Kullanıcı başarıyla güncellendi.',
    'User removed successfully.' => 'Kullanıcı başarıyla silindi.',
    'Unable to remove this user.' => 'Bu kullanıcı silinemiyor.',
    'Board updated successfully.' => 'Pano başarıyla güncellendi.',
    'Ready' => 'Hazır',
    'Backlog' => 'Bekleme listesi',
    'Work in progress' => 'İşlemde',
    'Done' => 'Tamamlandı',
    'Application version:' => 'Uygulama versiyonu:',
    'Id' => 'Kod',
    'Public link' => 'Dışa açık link',
    'Timezone' => 'Saat dilimi',
    'Sorry, I didn\'t find this information in my database!' => 'Üzgünüm, bu bilgiyi veri tabanımda bulamadım.',
    'Page not found' => 'Sayfa bulunamadı',
    'Complexity' => 'Zorluk seviyesi',
    'Task limit' => 'Görev limiti',
    'Task count' => 'Görev sayısı',
    'User' => 'Kullanıcı',
    'Comments' => 'Yorumlar',
    'Comment is required' => 'Yorum gerekli',
    'Comment added successfully.' => 'Yorum eklendi',
    'Unable to create your comment.' => 'Yorumunuz oluşturulamadı',
    'Due Date' => 'Bitiş Tarihi',
    'Invalid date' => 'Geçersiz tarihi',
    'Automatic actions' => 'Otomatik işlemler',
    'Your automatic action has been created successfully.' => 'Otomatik işlem başarıyla oluşturuldu',
    'Unable to create your automatic action.' => 'Otomatik işleminiz oluşturulamadı',
    'Remove an action' => 'Bir işlemi sil',
    'Unable to remove this action.' => 'Bu işlem silinemedi',
    'Action removed successfully.' => 'İşlem başarıyla silindi',
    'Automatic actions for the project "%s"' => '"%s" projesi için otomatik işlemler',
    'Add an action' => 'İşlem ekle',
    'Event name' => 'Durum adı',
    'Action' => 'İşlem',
    'Event' => 'Durum',
    'When the selected event occurs execute the corresponding action.' => 'Seçilen durum oluştuğunda ilgili eylemi gerçekleştir.',
    'Next step' => 'Sonraki adım',
    'Define action parameters' => 'İşlem parametrelerini düzenle',
    'Do you really want to remove this action: "%s"?' => 'Bu işlemi silmek istediğinize emin misiniz: "%s"?',
    'Remove an automatic action' => 'Bir otomatik işlemi sil',
    'Assign the task to a specific user' => 'Görevi bir kullanıcıya ata',
    'Assign the task to the person who does the action' => 'Görevi, işlemi gerçekleştiren kullanıcıya ata',
    'Duplicate the task to another project' => 'Görevi bir başka projeye kopyala',
    'Move a task to another column' => 'Bir görevi başka bir sütuna taşı',
    'Task modification' => 'Görev düzenleme',
    'Task creation' => 'Görev oluşturma',
    'Closing a task' => 'Bir görev kapatılıyor',
    'Assign a color to a specific user' => 'Bir kullanıcıya renk tanımla',
    'Position' => 'Pozisyon',
    'Duplicate to project' => 'Başka bir projeye kopyala',
    'Duplicate' => 'Kopya oluştur',
    'Link' => 'Bağlantı',
    'Comment updated successfully.' => 'Yorum güncellendi.',
    'Unable to update your comment.' => 'Yorum güncellenemedi.',
    'Remove a comment' => 'Bir yorumu sil',
    'Comment removed successfully.' => 'Yorum silindi.',
    'Unable to remove this comment.' => 'Bu yorum silinemiyor.',
    'Do you really want to remove this comment?' => 'Bu yorumu silmek istediğinize emin misiniz?',
    'Current password for the user "%s"' => 'Kullanıcı için mevcut şifre "%s"',
    'The current password is required' => 'Mevcut şifre gerekli',
    'Wrong password' => 'Yanlış şifre',
    'Unknown' => 'Bilinmeyen',
    'Last logins' => 'Son kullanıcı girişleri',
    'Login date' => 'Giriş tarihi',
    'Authentication method' => 'Doğrulama yöntemi',
    'IP address' => 'IP adresi',
    'User agent' => 'Kullanıcı Arayüzü',
    'Persistent connections' => 'Kalıcı bağlantılar',
    'No session.' => 'Oturum yok.',
    'Expiration date' => 'Geçerlilik sonu',
    'Remember Me' => 'Beni hatırla',
    'Creation date' => 'Oluşturulma tarihi',
    'Everybody' => 'Herkes',
    'Open' => 'Açık',
    'Closed' => 'Kapalı',
    'Search' => 'Ara',
    'Nothing found.' => 'Hiçbir şey bulunamadı.',
    'Due date' => 'Bitiş tarihi',
    'Description' => 'Açıklama',
    '%d comments' => '%d yorum',
    '%d comment' => '%d yorum',
    'Email address invalid' => 'E-posta adresi geçersiz',
    'Your external account is not linked anymore to your profile.' => 'Harici hesabınız artık profilinize bağlı değil',
    'Unable to unlink your external account.' => 'Harici hesabınızla bağlantı koparılamadı',
    'External authentication failed' => 'Harici hesap doğrulaması başarısız',
    'Your external account is linked to your profile successfully.' => 'Harici hesabınız profilinizle başarıyla bağlandı.',
    'Email' => 'E-posta',
    'Task removed successfully.' => 'Görev başarıyla silindi.',
    'Unable to remove this task.' => 'Görev silinemiyor.',
    'Remove a task' => 'Bir görevi sil',
    'Do you really want to remove this task: "%s"?' => 'Bu görevi silmek istediğinize emin misiniz: "%s"?',
    'Assign automatically a color based on a category' => 'Kategoriye göre otomatik renk ata',
    'Assign automatically a category based on a color' => 'Rengine göre otomatik kategori ata',
    'Task creation or modification' => 'Görev oluşturma veya düzenleme',
    'Category' => 'Kategori',
    'Category:' => 'Kategori:',
    'Categories' => 'Kategoriler',
    'Your category has been created successfully.' => 'Kategori başarıyla oluşturuldu.',
    'This category has been updated successfully.' => 'Kategori başarıyla güncellendi.',
    'Unable to update this category.' => 'Kategori güncellenemedi.',
    'Remove a category' => 'Bir kategoriyi sil',
    'Category removed successfully.' => 'Kategori başarıyla silindi.',
    'Unable to remove this category.' => 'Bu kategori silinemedi.',
    'Category modification for the project "%s"' => '"%s" projesi için kategori düzenleme',
    'Category Name' => 'Kategori adı',
    'Add a new category' => 'Yeni kategori ekle',
    'Do you really want to remove this category: "%s"?' => 'Bu kategoriyi silmek istediğinize emin misiniz: "%s"?',
    'All categories' => 'Tüm kategoriler',
    'No category' => 'Kategori Yok',
    'The name is required' => 'İsim gerekli',
    'Remove a file' => 'Dosya sil',
    'Unable to remove this file.' => 'Dosya silinemedi',
    'File removed successfully.' => 'Dosya silindi',
    'Attach a document' => 'Dosya ekle',
    'Do you really want to remove this file: "%s"?' => 'Bu dosyayı silmek istediğinize emin misiniz: "%s"?',
    'Attachments' => 'Ekler',
    'Edit the task' => 'Görevi değiştir',
    'Add a comment' => 'Yorum ekle',
    'Edit a comment' => 'Yorum değiştir',
    'Summary' => 'Özet',
    'Time tracking' => 'Süre Çizelgesi',
    'Estimate:' => 'Tahmini:',
    'Spent:' => 'Harcanan:',
    'Do you really want to remove this sub-task?' => 'Bu alt görevi silmek istediğinize emin misiniz',
    'Remaining:' => 'Kalan',
    'hours' => 'saat',
    'estimated' => 'tahmini',
    'Sub-Tasks' => 'Alt Görev',
    'Add a sub-task' => 'Alt görev ekle',
    'Original estimate' => 'Orjinal tahmin',
    'Create another sub-task' => 'Başka bir alt görev daha oluştur',
    'Time spent' => 'Geçen süre',
    'Edit a sub-task' => 'Alt görev düzenle',
    'Remove a sub-task' => 'Alt görev sil',
    'The time must be a numeric value' => 'Zaman alfanümerik bir değer olmalı',
    'Todo' => 'Yapılacaklar',
    'In progress' => 'Devam etmekte',
    'Sub-task removed successfully.' => 'Alt görev başarıyla silindi.',
    'Unable to remove this sub-task.' => 'Alt görev silinemedi.',
    'Sub-task updated successfully.' => 'Alt görev güncellendi.',
    'Unable to update your sub-task.' => 'Alt görev güncellenemiyor.',
    'Unable to create your sub-task.' => 'Alt görev oluşturulamadı.',
    'Maximum size: ' => 'Maksimum boyutu',
    'Display another project' => 'Başka bir proje göster',
    'Created by %s' => '%s tarafından oluşturuldu',
    'Tasks Export' => 'Görevleri dışa aktar',
    'Start Date' => 'Başlangıç tarihi',
    'Execute' => 'Gerçekleştir',
    'Task Id' => 'Görev Kimliği',
    'Creator' => 'Oluşturan',
    'Modification date' => 'Değişiklik tarihi',
    'Completion date' => 'Tamamlanma tarihi',
    'Clone' => 'Kopya oluştur',
    'Project cloned successfully.' => 'Proje kopyası başarıyla oluşturuldu.',
    'Unable to clone this project.' => 'Proje kopyası oluşturulamıyor.',
    'Enable email notifications' => 'E-posta bilgilendirmesini aç',
    'Task position:' => 'Görev pozisyonu',
    'The task #%d has been opened.' => '#%d numaralı görev açıldı.',
    'The task #%d has been closed.' => '#%d numaralı görev kapatıldı.',
    'Sub-task updated' => 'Alt görev güncellendi',
    'Title:' => 'Başlık',
    'Status:' => 'Durum',
    'Assignee:' => 'Sorumlu:',
    'Time tracking:' => 'Zaman takibi',
    'New sub-task' => 'Yeni alt görev',
    'New attachment added "%s"' => 'Yeni dosya "%s" eklendi.',
    'New comment posted by %s' => '%s tarafından yeni yorum eklendi',
    'New comment' => 'Yeni yorum',
    'Comment updated' => 'Yorum güncellendi',
    'New subtask' => 'Yeni alt görev',
    'I only want to receive notifications for these projects:' => 'Yalnızca bu projelerle ilgili bildirim almak istiyorum:',
    'view the task on Kanboard' => 'bu görevi Kanboard üzerinde göster',
    'Public access' => 'Dışa açık erişim',
    'Disable public access' => 'Dışa açık erişimi kapat',
    'Enable public access' => 'Dışa açık erişimi aç',
    'Public access disabled' => 'Dışa açık erişim kapatıldı',
    'Move the task to another project' => 'Görevi başka projeye taşı',
    'Move to project' => 'Başka projeye taşı',
    'Do you really want to duplicate this task?' => 'Bu görevin kopyasını oluşturmak istediğinize emin misiniz?',
    'Duplicate a task' => 'Görevin kopyasını oluştur',
    'External accounts' => 'Dış hesaplar',
    'Account type' => 'Hesap türü',
    'Local' => 'Yerel',
    'Remote' => 'Uzak',
    'Enabled' => 'Etkinleştirildi',
    'Disabled' => 'Devre dışı bırakıldı',
    'Login:' => 'Kullanıcı adı',
    'Full Name:' => 'Ad',
    'Email:' => 'E-posta',
    'Notifications:' => 'Bildirimler:',
    'Notifications' => 'Bildirimler',
    'Account type:' => 'Hesap türü:',
    'Edit profile' => 'Profili değiştir',
    'Change password' => 'Şifre değiştir',
    'Password modification' => 'Şifre değişimi',
    'External authentications' => 'Dış kimlik doğrulamaları',
    'Never connected.' => 'Hiç bağlanmamış.',
    'No external authentication enabled.' => 'Dış kimlik doğrulama kapalı.',
    'Password modified successfully.' => 'Şifre başarıyla değiştirildi.',
    'Unable to change the password.' => 'Şifre değiştirilemiyor.',
    'Change category' => 'Kategori değiştirme',
    '%s updated the task %s' => '%s kullanıcısı %s görevini güncelledi',
    '%s opened the task %s' => '%s kullanıcısı %s görevini açtı',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s kullanıcısı %s görevini #%d pozisyonu "%s" sütununa taşıdı',
    '%s moved the task %s to the column "%s"' => '%s kullanıcısı %s görevini "%s" sütununa taşıdı',
    '%s created the task %s' => '%s kullanıcısı %s görevini oluşturdu',
    '%s closed the task %s' => '%s kullanıcısı %s görevini kapattı',
    '%s created a subtask for the task %s' => '%s kullanıcısı %s görevi için bir alt görev oluşturdu',
    '%s updated a subtask for the task %s' => '%s kullanıcısı %s görevinin bir alt görevini güncelledi',
    'Assigned to %s with an estimate of %s/%sh' => '%s kullanıcısına tahmini %s/%s saat tamamlanma süresi ile atanmış',
    'Not assigned, estimate of %sh' => 'Kimseye atanmamış, tahmini süre %s saat',
    '%s updated a comment on the task %s' => '%s kullanıcısı %s görevinde bir yorumu güncelledi',
    '%s commented the task %s' => '%s kullanıcısı %s görevine yorum ekledi',
    '%s\'s activity' => '%s\'in aktivitesi',
    'RSS feed' => 'RSS kaynağı',
    '%s updated a comment on the task #%d' => '%s kullanıcısı #%d nolu görevde bir yorumu güncelledi',
    '%s commented on the task #%d' => '%s kullanıcısı #%d nolu göreve yorum ekledi',
    '%s updated a subtask for the task #%d' => '%s kullanıcısı #%d nolu görevin bir alt görevini güncelledi',
    '%s created a subtask for the task #%d' => '%s kullanıcısı #%d nolu göreve bir alt görev ekledi',
    '%s updated the task #%d' => '%s kullanıcısı #%d nolu görevi güncelledi',
    '%s created the task #%d' => '%s kullanıcısı #%d nolu görevi oluşturdu',
    '%s closed the task #%d' => '%s kullanıcısı #%d nolu görevi kapattı',
    '%s opened the task #%d' => '%s kullanıcısı #%d nolu görevi açtı',
    'Activity' => 'Aktivite',
    'Default values are "%s"' => 'Varsayılan değerler "%s"',
    'Default columns for new projects (Comma-separated)' => 'Yeni projeler için varsayılan sütunlar (virgül ile ayrılmış)',
    'Task assignee change' => 'Göreve atanan kullanıcı değişikliği',
    '%s changed the assignee of the task #%d to %s' => '%s kullanıcısı #%d nolu görevin sorumlusunu %s olarak değiştirdi',
    '%s changed the assignee of the task %s to %s' => '%s kullanıcısı %s görevinin sorumlusunu %s olarak değiştirdi',
    'New password for the user "%s"' => '"%s" kullanıcısı için yeni şifre',
    'Choose an event' => 'Bir durum seçin',
    'Create a task from an external provider' => 'Dış sağlayıcı ile bir görev oluştur',
    'Change the assignee based on an external username' => 'Dış kaynaklı kullanıcı adı ile göreve atananı değiştir',
    'Change the category based on an external label' => 'Dış kaynaklı bir etiket ile kategori değiştir',
    'Reference' => 'Referans',
    'Label' => 'Etiket',
    'Database' => 'Veritabanı',
    'About' => 'Hakkında',
    'Database driver:' => 'Veritabanı sürücüsü:',
    'Board settings' => 'Pano ayarları',
    'Webhook settings' => 'Webhook ayarları',
    'Reset token' => 'Anahtarı sıfırla',
    'API endpoint:' => 'API bitiş noktası:',
    'Refresh interval for personal board' => 'Özel panolar için yenileme sıklığı',
    'Refresh interval for public board' => 'Dışa açık panolar için yenileme sıklığı',
    'Task highlight period' => 'Görevi öne çıkarma süresi',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Bir görevin yeni değiştirilmiş sayılması için süre (saniye olarak) (Bu özelliği iptal etmek için 0, varsayılan değer 2 gün)',
    'Frequency in second (60 seconds by default)' => 'Saniye olarak frekans (varsayılan 60 saniye)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Saniye olarak frekans (Bu özelliği iptal etmek için 0, varsayılan değer 10 saniye)',
    'Application URL' => 'Uygulama URL',
    'Token regenerated.' => 'Anahtar yeniden oluşturuldu.',
    'Date format' => 'Tarih formatı',
    'ISO format is always accepted, example: "%s" and "%s"' => 'ISO formatı her zaman kabul edilir, örneğin: "%s" ve "%s"',
    'New personal project' => 'Yeni özel proje',
    'This project is personal' => 'Bu proje özel',
    'Add' => 'Ekle',
    'Start date' => 'Başlangıç tarihi',
    'Time estimated' => 'Tahmini süre',
    'There is nothing assigned to you.' => 'Size atanan hiçbir şey yok.',
    'My tasks' => 'Görevlerim',
    'Activity stream' => 'Güncel olay akışı',
    'Dashboard' => 'Pano',
    'Confirmation' => 'Onay',
    'Webhooks' => 'Web Kancaları',
    'API' => 'API',
    'Create a comment from an external provider' => 'Dış sağlayıcı ile bir yorum oluştur',
    'Project management' => 'Proje yönetimi',
    'Columns' => 'Sütunlar',
    'Task' => 'Görev',
    'Percentage' => 'Yüzde',
    'Number of tasks' => 'Görev sayısı',
    'Task distribution' => 'Görev dağılımı',
    'Analytics' => 'Analiz',
    'Subtask' => 'Alt görev',
    'User repartition' => 'Kullanıcı dağılımı',
    'Clone this project' => 'Projenin kopyasını oluştur',
    'Column removed successfully.' => 'Sütun başarıyla kaldırıldı.',
    'Not enough data to show the graph.' => 'Grafik gösterimi için yeterli veri yok.',
    'Previous' => 'Önceki',
    'The id must be an integer' => 'ID bir tamsayı olmalı',
    'The project id must be an integer' => 'Proje numarası bir tam sayı olmalı',
    'The status must be an integer' => 'Durum bir tam sayı olmalı',
    'The subtask id is required' => 'Alt görev numarası gerekli',
    'The subtask id must be an integer' => 'Alt görev numarası bir tam sayı olmalı',
    'The task id is required' => 'Görev numarası gerekli',
    'The task id must be an integer' => 'Görev numarası bir tam sayı olmalı',
    'The user id must be an integer' => 'Kullanıcı numarası bir tam sayı olmalı',
    'This value is required' => 'Bu değer gerekli',
    'This value must be numeric' => 'Bu değer sayı olmalı',
    'Unable to create this task.' => 'Bu görev oluşturulamıyor.',
    'Cumulative flow diagram' => 'Kümülatif akış diyagramı',
    'Daily project summary' => 'Günlük proje özeti',
    'Daily project summary export' => 'Günlük proje özetini dışa aktar',
    'Exports' => 'Dışa aktarımlar',
    'This export contains the number of tasks per column grouped per day.' => 'Bu dışa aktarım günlük gruplanmış olarak her sütundaki görev sayısını içerir.',
    'Active swimlanes' => 'Aktif Kulvar',
    'Add a new swimlane' => 'Yeni bir Kulvar ekle',
    'Default swimlane' => 'Varsayılan Kulvar',
    'Do you really want to remove this swimlane: "%s"?' => 'Bu Kulvarı silmek istediğinize emin misiniz?: "%s"?',
    'Inactive swimlanes' => 'Pasif Kulvarlar',
    'Remove a swimlane' => 'Kulvarı sil',
    'Swimlane modification for the project "%s"' => '"%s" Projesi için Kulvar değişikliği',
    'Swimlane removed successfully.' => 'Kulvar başarıyla kaldırıldı.',
    'Swimlanes' => 'Kulvarlar',
    'Swimlane updated successfully.' => 'Kulvar başarıyla güncellendi.',
    'Unable to remove this swimlane.' => 'Bu Kulvarı silmek mümkün değil.',
    'Unable to update this swimlane.' => 'Bu Kulvarı değiştirmek mümkün değil.',
    'Your swimlane has been created successfully.' => 'Kulvar başarıyla oluşturuldu.',
    'Example: "Bug, Feature Request, Improvement"' => 'Örnek: "Sorun, Özellik talebi, İyileştirme"',
    'Default categories for new projects (Comma-separated)' => 'Yeni projeler için varsayılan kategoriler (Virgül ile ayrılmış)',
    'Integrations' => 'Entegrasyon',
    'Integration with third-party services' => 'Dış servislerle entegrasyon',
    'Subtask Id' => 'Alt görev No:',
    'Subtasks' => 'Alt görevler',
    'Subtasks Export' => 'Alt görevleri dışa aktar',
    'Task Title' => 'Görev Başlığı',
    'Untitled' => 'Başlıksız',
    'Application default' => 'Uygulama varsayılanları',
    'Language:' => 'Dil:',
    'Timezone:' => 'Saat dilimi:',
    'All columns' => 'Tüm sütunlar',
    'Next' => 'Sonraki',
    '#%d' => '#%d',
    'All swimlanes' => 'Tüm Kulvarlar',
    'All colors' => 'Tüm Renkler',
    'Moved to column %s' => '%s Sütununa taşındı',
    'User dashboard' => 'Kullanıcı Anasayfası',
    'Allow only one subtask in progress at the same time for a user' => 'Bir kullanıcı için aynı anda yalnızca bir alt göreve izin ver',
    'Edit column "%s"' => '"%s" sütununu değiştir',
    'Select the new status of the subtask: "%s"' => '"%s" alt görevi için yeni durum seçin.',
    'Subtask timesheet' => 'Alt görev için süre tablosu',
    'There is nothing to show.' => 'Gösterilecek hiçbir şey yok.',
    'Time Tracking' => 'Süre Çizelgesi',
    'You already have one subtask in progress' => 'Zaten işlemde olan bir alt görev var',
    'Which parts of the project do you want to duplicate?' => 'Projenin hangi kısımlarının kopyasını oluşturmak istiyorsunuz?',
    'Disallow login form' => 'Giriş formu erişimini engelle',
    'Start' => 'Başlangıç',
    'End' => 'Bitiş',
    'Task age in days' => 'Görev yaşı gün olarak',
    'Days in this column' => 'Bu sütunda geçirilen gün',
    '%dd' => '%dG',
    'Add a new link' => 'Yeni link ekle',
    'Do you really want to remove this link: "%s"?' => '"%s" linkini gerçekten silmek istiyor musunuz?',
    'Do you really want to remove this link with task #%d?' => '#%d numaralı görev ile linki gerçekten silmek istiyor musunuz?',
    'Field required' => 'Bu alan gerekli',
    'Link added successfully.' => 'Link başarıyla eklendi.',
    'Link updated successfully.' => 'Link başarıyla güncellendi.',
    'Link removed successfully.' => 'Link başarıyla silindi.',
    'Link labels' => 'Link etiketleri',
    'Link modification' => 'Link değiştirme',
    'Opposite label' => 'Zıt etiket',
    'Remove a link' => 'Bir link silmek',
    'The labels must be different' => 'Etiketler farklı olmalı',
    'There is no link.' => 'Hiç bir bağ yok',
    'This label must be unique' => 'Bu etiket tek olmalı',
    'Unable to create your link.' => 'Link oluşturulamadı.',
    'Unable to update your link.' => 'Link güncellenemiyor.',
    'Unable to remove this link.' => 'Link kaldırılamıyor',
    'relates to' => 'şununla ilgili',
    'blocks' => 'şunu engelliyor',
    'is blocked by' => 'şunun tarafından engelleniyor',
    'duplicates' => 'şunun kopyasını oluşturuyor',
    'is duplicated by' => 'şunun tarafından kopyası oluşturuluyor',
    'is a child of' => 'şunun astı',
    'is a parent of' => 'şunun üstü',
    'targets milestone' => 'şu kilometre taşını hedefliyor',
    'is a milestone of' => 'şunun için bir kilometre taşı',
    'fixes' => 'düzeltiyor',
    'is fixed by' => 'şunun tarafından düzeltildi',
    'This task' => 'Bu görev',
    '<1h' => '<1s',
    '%dh' => '%ds',
    'Expand tasks' => 'Görevleri genişlet',
    'Collapse tasks' => 'Görevleri daralt',
    'Expand/collapse tasks' => 'Görevleri genişlet/daralt',
    'Close dialog box' => 'İletiyi kapat',
    'Submit a form' => 'Formu gönder',
    'Board view' => 'Pano görünümü',
    'Keyboard shortcuts' => 'Klavye kısayolları',
    'Open board switcher' => 'Pano seçim listesini aç',
    'Application' => 'Uygulama',
    'Compact view' => 'Ekrana sığdır',
    'Horizontal scrolling' => 'Geniş görünüm',
    'Compact/wide view' => 'Ekrana sığdır / Geniş görünüm',
    'Currency' => 'Para birimi',
    'Personal project' => 'Özel proje',
    'AUD - Australian Dollar' => 'AUD - Avustralya Doları',
    'CAD - Canadian Dollar' => 'CAD - Kanada Doları',
    'CHF - Swiss Francs' => 'CHF - İsviçre Frangı',
    'Custom Stylesheet' => 'Özel Sitil Css',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - İngiliz Paund',
    'INR - Indian Rupee' => 'INR - Hint Rupesi',
    'JPY - Japanese Yen' => 'JPY - Japon Yeni',
    'NZD - New Zealand Dollar' => 'NZD - Yeni Zelanda Doları',
    'PEN - Peruvian Sol' => 'PEN - Peru Solü',
    'RSD - Serbian dinar' => 'Sırp Dinarı',
    'CNY - Chinese Yuan' => 'CNY - Çin Yuanı',
    'USD - US Dollar' => 'USD Amerikan Doları',
    'VES - Venezuelan Bolívar' => 'VES - Venezuela Bolivarı',
    'Destination column' => 'Hedef Sütun',
    'Move the task to another column when assigned to a user' => 'Bir kullanıcıya atandığında görevi başka bir sütuna taşı',
    'Move the task to another column when assignee is cleared' => 'Atanmış kullanıcı kaldırıldığında görevi başka bir sütuna taşı',
    'Source column' => 'Kaynak sütun',
    'Transitions' => 'Geçişler',
    'Executer' => 'Uygulayıcı',
    'Time spent in the column' => 'Sütunda geçen süre',
    'Task transitions' => 'Görev geçişleri',
    'Task transitions export' => 'Görev geçişlerini dışa aktar',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Bu rapor her bir görevin sütunlar arası geçişlerini tarih, kullanıcı ve sütunda harcanan zaman detaylarıyla içerir.',
    'Currency rates' => 'Döviz kurları',
    'Rate' => 'Kurlar',
    'Change reference currency' => 'Referans kur değiştir',
    'Reference currency' => 'Referans kur',
    'The currency rate has been added successfully.' => 'Kur başarıyla eklendi',
    'Unable to add this currency rate.' => 'Bu kur eklenemedi',
    'Webhook URL' => 'Web kancası URL',
    '%s removed the assignee of the task %s' => '%s, %s görevinin atanan bilgisini kaldırdı',
    'Information' => 'Bilgi',
    'Check two factor authentication code' => 'Çift-Kademeli doğrulama kodunu kontrol et',
    'The two factor authentication code is not valid.' => 'Çift-Kademeli doğrulama kodu geçersiz',
    'The two factor authentication code is valid.' => 'Çift-Kademeli doğrulama kodu onaylandı',
    'Code' => 'Kod',
    'Two factor authentication' => 'Çift-Kademeli doğrulama',
    'This QR code contains the key URI: ' => 'Bu QR kodu anahtar URI içerir',
    'Check my code' => 'Kodu kontrol et',
    'Secret key: ' => 'Gizli anahtar',
    'Test your device' => 'Cihazınızı test edin',
    'Assign a color when the task is moved to a specific column' => 'Görev belirli bir sütuna taşındığında rengini değiştir',
    '%s via Kanboard' => '%s Kanboard ile',
    'Burndown chart' => 'Kalan iş grafiği',
    'This chart show the task complexity over the time (Work Remaining).' => 'Bu grafik zorluk seviyesini zamana göre gösterir (kalan iş)',
    'Screenshot taken %s' => 'Ekran görüntüsü alındı %s',
    'Add a screenshot' => 'Bir ekran görüntüsü ekle',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Bir ekran görüntüsü alın ve buraya yapıştırmak için CTRL+V veya  ⌘+V tuşlarına basın.',
    'Screenshot uploaded successfully.' => 'Ekran görüntüsü başarıyla yüklendi',
    'SEK - Swedish Krona' => ' SEK - İsveç Kronu',
    'Identifier' => 'Kimlik',
    'Disable two factor authentication' => 'Çift-Kademeli doğrulamayı iptal et',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Bu kullanıcı için Çift-Kademeli doğrulamayı iptal etmek istediğinize emin misiniz: "%s"?',
    'Edit link' => 'Linki düzenle',
    'Start to type task title...' => 'Görev başlığını yazmaya başlayın...',
    'A task cannot be linked to itself' => 'Bir görevden kendine link atanamaz',
    'The exact same link already exists' => 'Birebir aynı link zaten var',
    'Recurrent task is scheduled to be generated' => 'Tekrarlanan görev oluşturulması zamanlandı',
    'Score' => 'Skor',
    'The identifier must be unique' => 'Kimlik özgün olmalı',
    'This linked task id doesn\'t exists' => 'Link oluşturulan görec kodu mevcut değil',
    'This value must be alphanumeric' => 'Bu değer alfanumerik olmalı',
    'Edit recurrence' => 'Tekrarlanmayı düzenle',
    'Generate recurrent task' => 'Tekrarlanan görev oluştur',
    'Trigger to generate recurrent task' => 'Tekrarlanan görev oluşturmak için tetikleyici',
    'Factor to calculate new due date' => 'Yeni tamamlanma tarihi için hesaplama faktörü',
    'Timeframe to calculate new due date' => 'Yeni tamamlanma tarihinin hesaplanması için zaman dilimi',
    'Base date to calculate new due date' => 'Yeni tamamlanma tarihinin hesaplanması için baz alınacak tarih',
    'Action date' => 'Hareket tarihi',
    'Base date to calculate new due date: ' => 'Yeni tamamlanma tarihinin hesaplanması için baz alınacak tarih',
    'This task has created this child task: ' => 'Bu görev şu alt görevi oluşturdu:',
    'Day(s)' => 'Gün(ler)',
    'Existing due date' => 'Mevcut tamamlanma tarihi',
    'Factor to calculate new due date: ' => 'Yeni tamamlanma tarihi için hesaplama faktörü',
    'Month(s)' => 'Ay(lar)',
    'This task has been created by: ' => 'Bu görev şunun tarafından oluşturuldu:',
    'Recurrent task has been generated:' => 'Tekrarlanan görev oluşturuldu:',
    'Timeframe to calculate new due date: ' => 'Yeni tamamlanma tarihinin hesaplanması için zaman dilimi',
    'Trigger to generate recurrent task: ' => 'Tekrarlanan görev oluşturmak için tetikleyici',
    'When task is closed' => 'Görev kapatıldığı zaman',
    'When task is moved from first column' => 'Görev ilk sütundan taşındığı zaman',
    'When task is moved to last column' => 'Görev son sütuna taşındığı zaman',
    'Year(s)' => 'Yıl(lar)',
    'Project settings' => 'Proje ayarları',
    'Automatically update the start date' => 'Başlangıç tarihini otomatik olarak güncelle',
    'iCal feed' => 'iCal akışı',
    'Preferences' => 'Ayarlar',
    'Security' => 'Güvenlik',
    'Two factor authentication disabled' => 'Çift-Kademeli doğrulamayı devre dışı bırak',
    'Two factor authentication enabled' => 'Çift-Kademeli doğrulamayı etkinleştir',
    'Unable to update this user.' => 'Bu kullanıcı güncellenemiyor',
    'There is no user management for personal projects.' => 'Özel projeler için kullanıcı yönetimi yoktur.',
    'User that will receive the email' => 'Email alacak kullanıcı',
    'Email subject' => 'Email başlığı',
    'Date' => 'Tarih',
    'Add a comment log when moving the task between columns' => 'Görevi sütunlar arasında taşırken yorum kaydı ekle',
    'Move the task to another column when the category is changed' => 'Kategori değiştirildiğinde görevi başka sütuna taşı',
    'Send a task by email to someone' => 'Bir görevi email ile birine gönder',
    'Reopen a task' => 'Bir görevi tekrar aç',
    'Notification' => 'Uyarılar',
    '%s moved the task #%d to the first swimlane' => '%s, #%d görevini birinci kulvara taşıdı',
    'Swimlane' => 'Kulvar',
    '%s moved the task %s to the first swimlane' => '%s, %s görevini ilk kulvara taşıdı',
    '%s moved the task %s to the swimlane "%s"' => '%s, %s görevini "%s" kulvarına taşıdı',
    'This report contains all subtasks information for the given date range.' => 'Bu rapor belirtilen tarih aralığında tüm alt görev bilgilerini içerir.',
    'This report contains all tasks information for the given date range.' => 'Bu rapor belirtilen tarih aralığında tüm görev bilgilerini içerir.',
    'Project activities for %s' => '%s için proje aktiviteleri',
    'view the board on Kanboard' => 'Pano yu Kanboard\'da görüntüle',
    'The task has been moved to the first swimlane' => 'Görev birinci kulvara taşındı',
    'The task has been moved to another swimlane:' => 'Görev başka bir kulvara taşındı:',
    'New title: %s' => 'Yeni başlık: %s',
    'The task is not assigned anymore' => 'Görev artık atanmamış',
    'New assignee: %s' => 'Yeni atanan: %s',
    'There is no category now' => 'Şu anda kategori yok',
    'New category: %s' => 'Yeni kategori: %s',
    'New color: %s' => 'Yeni renk: %s',
    'New complexity: %d' => 'Yeni zorluk seviyesi: %d',
    'The due date has been removed' => 'Tamamlanma tarihi silindi',
    'There is no description anymore' => 'Artık açıklama yok',
    'Recurrence settings has been modified' => 'Tekrarlanma ayarları değiştirildi',
    'Time spent changed: %sh' => 'Geçen süre değiştirildi: %sh',
    'Time estimated changed: %sh' => 'Tahmini süre değiştirildi: %sh',
    'The field "%s" has been updated' => '"%s" hanesi değiştirildi',
    'The description has been modified:' => 'Açıklama değiştirildi',
    'Do you really want to close the task "%s" as well as all subtasks?' => '"%s" görevini ve tüm alt görevlerini kapatmak istediğinize emin misiniz?',
    'I want to receive notifications for:' => 'Bununla ilgili bildirimler almak istiyorum:',
    'All tasks' => 'Tüm görevler',
    'Only for tasks assigned to me' => 'Yalnızca bana atanmış görevler için',
    'Only for tasks created by me' => 'Yalnızca benim oluşturduğum görevler için',
    'Only for tasks created by me and tasks assigned to me' => 'Yalnızca benim oluşturduğum ve bana atanmış görevler için',
    '%%Y-%%m-%%d' => '%%Y-%%m-%%d',
    'Total for all columns' => 'Tüm sütunlar için toplam',
    'You need at least 2 days of data to show the chart.' => 'Grafiği göstermek için en az iki günlük veriye ihtiyaç var.',
    '<15m' => '<15dk',
    '<30m' => '<30dk',
    'Stop timer' => 'Zamanlayıcıyı durdur',
    'Start timer' => 'Zamanlayıcıyı başlat',
    'My activity stream' => 'Olay akışım',
    'Search tasks' => 'Görevleri ara',
    'Reset filters' => 'Filtreleri sıfırla',
    'My tasks due tomorrow' => 'Yarına tamamlanması gereken görevlerim',
    'Tasks due today' => 'Bugün tamamlanması gereken görevler',
    'Tasks due tomorrow' => 'Yarına tamamlanması gereken görevler',
    'Tasks due yesterday' => 'Dün tamamlanmış olması gereken görevler',
    'Closed tasks' => 'Kapatılmış görevler',
    'Open tasks' => 'Açık görevler',
    'Not assigned' => 'Atanmamış',
    'View advanced search syntax' => 'Gelişmiş arama kodlarını göster',
    'Overview' => 'Özet Görünüm',
    'Board/Calendar/List view' => 'Pano/Takvim/Liste görünümü',
    'Switch to the board view' => 'Pano görünümüne geç',
    'Switch to the list view' => 'Liste görünümüne geç',
    'Go to the search/filter box' => 'Arama/Filtreleme kutusuna git',
    'There is no activity yet.' => 'Henüz bir aktivite yok.',
    'No tasks found.' => 'Hiç görev bulunamadı.',
    'Keyboard shortcut: "%s"' => 'Klavye kısayolu: "%s"',
    'List' => 'Liste',
    'Filter' => 'Filtre',
    'Advanced search' => 'Gelişmiş arama',
    'Example of query: ' => 'Sorgu örneği',
    'Search by project: ' => 'Projeye göre ara',
    'Search by column: ' => 'Sütuna göre ara',
    'Search by assignee: ' => 'Atanana göre ara',
    'Search by color: ' => 'Renge göre ara',
    'Search by category: ' => 'Kategoriye göre ara',
    'Search by description: ' => 'Açıklamaya göre ara',
    'Search by due date: ' => 'Tamamlanma tarihine göre ara',
    'Average time spent in each column' => 'Her bir sütunda geçirilen ortalama süre',
    'Average time spent' => 'Geçen ortalama süre',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Bu grafik son %d görev için  her bir sütunda geçirilen ortalama süreyi gösterir.',
    'Average Lead and Cycle time' => 'Ortalama teslim ve çevrim süresi',
    'Average lead time: ' => 'Ortalama teslim süresi',
    'Average cycle time: ' => 'Ortalama çevrim süresi',
    'Cycle Time' => 'Çevrim süresi',
    'Lead Time' => 'Teslim süresi',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Bu grafik son %d görev için zaman içinde gerçekleşen ortalama teslim ve çevrim sürelerini gösterir.',
    'Average time into each column' => 'Her bir sütunda ortalama zaman',
    'Lead and cycle time' => 'Teslim ve çevrim süresi',
    'Lead time: ' => 'Teslim süresi: ',
    'Cycle time: ' => 'Çevrim süresi: ',
    'Time spent in each column' => 'Her sütunda geçen süre',
    'The lead time is the duration between the task creation and the completion.' => 'Teslim süresi, görevin oluşturulması ile tamamlanması arasında geçen süredir.',
    'The cycle time is the duration between the start date and the completion.' => 'Çevrim süresi, görevin başlangıç tarihi ile tamamlanması arasında geçen süredir.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Eğer görev henüz kapatılmamışsa, tamamlanma tarihi yerine şu anki tarih kullanılır.',
    'Set the start date automatically' => 'Başlangıç tarihini otomatik olarak belirle',
    'Edit Authentication' => 'Doğrulamayı düzenle',
    'Remote user' => 'Uzak kullanıcı',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Uzak kullanıcıların şifreleri Kanboard veritabanında saklanmaz, örnek: LDAP, Google ve Github hesapları',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Eğer giriş formuna erişimi engelleyi seçerseniz, giriş formuna girilen bilgiler gözardı edilir.',
    'Default task color' => 'Varsayılan görev rengi',
    'This feature does not work with all browsers.' => 'Bu özellik tüm tarayıcılarla çalışmaz',
    'There is no destination project available.' => 'Seçilebilecek hedef proje yok.',
    'Trigger automatically subtask time tracking' => 'Altgörev zamanlayıcıyı otomatik olarak başlat',
    'Include closed tasks in the cumulative flow diagram' => 'Kümülatif akış diyagramında kapatılmış görevleri de dahil et',
    'Current swimlane: %s' => 'Geçerli kulvar: %s',
    'Current column: %s' => 'Geçerli sütun: %s',
    'Current category: %s' => 'Geçerli kategori: %s',
    'no category' => 'kategori yok',
    'Current assignee: %s' => 'Geçerli atanan: %s',
    'not assigned' => 'atanmamış',
    'Author:' => 'Yazar',
    'contributors' => 'Katkı sağlayanlar',
    'License:' => 'Lisans:',
    'License' => 'Lisans',
    'Enter the text below' => 'Aşağıdaki metni girin',
    'Start date:' => 'Başlangıç tarihi:',
    'Due date:' => 'Tamamlanması gereken tarih:',
    'People who are project managers' => 'Proje müdürü olan kişiler',
    'People who are project members' => 'Proje üyesi olan kişiler',
    'NOK - Norwegian Krone' => ' NOK - Norveç Kronu',
    'Show this column' => 'Bu sütunu göster',
    'Hide this column' => 'Bu sütunu gizle',
    'End date' => 'Bitiş tarihi',
    'Users overview' => 'Kullanıcılara genel bakış',
    'Members' => 'Üyeler',
    'Shared project' => 'Paylaşılan proje',
    'Project managers' => 'Proje müdürleri',
    'Projects list' => 'Proje listesi',
    'End date:' => 'Bitiş tarihi:',
    'Change task color when using a specific task link' => 'Belirli bir görev bağlantısı kullanıldığında görevin rengini değiştir',
    'Task link creation or modification' => 'Görev bağlantısı oluşturulması veya değiştirilmesi',
    'Milestone' => 'Kilometre taşı',
    'Reset the search/filter box' => 'Arama/Filtre kutusunu sıfırla',
    'Documentation' => 'Dokümantasyon',
    'Author' => 'Yazar',
    'Version' => 'Versiyon',
    'Plugins' => 'Eklentiler',
    'There is no plugin loaded.' => 'Yüklenmiş bir eklendi yok',
    'My notifications' => 'Bildirimlerim',
    'Custom filters' => 'Özel filtreler',
    'Your custom filter has been created successfully.' => 'Özel filtreleriniz başarıyla oluşturuldu.',
    'Unable to create your custom filter.' => 'Özel filtreniz oluşturulamadı.',
    'Custom filter removed successfully.' => 'Özel filtreniz başarıyla silindi.',
    'Unable to remove this custom filter.' => 'Bu özel filtre silinemiyor.',
    'Edit custom filter' => 'Özel filtreyi düzenle',
    'Your custom filter has been updated successfully.' => 'Özel filtreleriniz başarıyla güncellendi.',
    'Unable to update custom filter.' => 'Özel filtre güncellenemiyor.',
    'Web' => 'İnternet',
    'New attachment on task #%d: %s' => '#%d görevinde yeni dosya: %s',
    'New comment on task #%d' => '#%d görevinde yeni yorum',
    'Comment updated on task #%d' => '#%d görevinde yorum güncellendi',
    'New subtask on task #%d' => '#%d görevinde yeni alt görev',
    'Subtask updated on task #%d' => '#%d görevinde alt görev güncellendi',
    'New task #%d: %s' => 'Yeni #%d görevi: %s',
    'Task updated #%d' => '#%d görevi güncellendi',
    'Task #%d closed' => '#%d görevi kapatıldı',
    'Task #%d opened' => '#%d görevi oluşturuldu',
    'Column changed for task #%d' => '#%d görevinin sütunu değişti',
    'New position for task #%d' => '#%d görevinin konumu değişti',
    'Swimlane changed for task #%d' => '#%d görevinin kulvarı değişti',
    'Assignee changed on task #%d' => '#%d görevine atanan değişti',
    '%d overdue tasks' => '%d gecikmiş görev',
    'No notification.' => 'Yeni bildirim yok.',
    'Mark all as read' => 'Tümünü okunmuş olarak işaretle',
    'Mark as read' => 'Okunmuş olarak işaretle',
    'Total number of tasks in this column across all swimlanes' => 'Bu sutündaki görev sayısının tüm kulvarlardaki toplamı',
    'Collapse swimlane' => 'Kulvarı daralt',
    'Expand swimlane' => 'Kulvarı genişlet',
    'Add a new filter' => 'Yeni bir filtre ekle',
    'Share with all project members' => 'Tüm proje üyeleriyle paylaş',
    'Shared' => 'Paylaşılan',
    'Owner' => 'Sahibi',
    'Unread notifications' => 'Okunmamış bildirimler',
    'Notification methods:' => 'Bildirim yöntemleri:',
    'Unable to read your file' => 'Dosya okunamıyor',
    '%d task(s) have been imported successfully.' => '%d görev başarıyla içeri aktarıldı.',
    'Nothing has been imported!' => 'Hiçbir şey içeri aktarılamadı!',
    'Import users from CSV file' => 'CSV dosyasından kullanıcıları içeri aktar',
    '%d user(s) have been imported successfully.' => '%d kullanıcı başarıyla içeri aktarıldı.',
    'Comma' => 'Virgül',
    'Semi-colon' => 'Noktalı virgül',
    'Tab' => 'Tab',
    'Vertical bar' => 'Dikey çizgi',
    'Double Quote' => 'Tırnak işareti',
    'Single Quote' => 'Kesme işareti',
    '%s attached a file to the task #%d' => '%s, #%d görevine bir dosya ekledi.',
    'There is no column or swimlane activated in your project!' => 'Projenizde etkinleştirilmiş hiç bir sütun veya kulvar yok!',
    'Append filter (instead of replacement)' => 'Fıltreye ekle (üzerine yazmak yerine)',
    'Append/Replace' => 'Ekle/Üzerine yaz',
    'Append' => 'Ekle',
    'Replace' => 'Üzerine yaz',
    'Import' => 'İçeri aktar',
    'Change sorting' => 'sıralamayı değiştir',
    'Tasks Importation' => 'Görevleri içeri aktar',
    'Delimiter' => 'Ayırıcı',
    'Enclosure' => 'Enclosure',
    'CSV File' => 'CSV Dosyası',
    'Instructions' => 'Yönergeler',
    'Your file must use the predefined CSV format' => 'Dosyanız önceden belirlenmiş CSV formatını kullanmalı',
    'Your file must be encoded in UTF-8' => 'Dosyanız UTF-8 kodlamasında olmalı',
    'The first row must be the header' => 'İlk satır başlık olmalı',
    'Duplicates are not verified for you' => 'Çift girişler sizin için onaylanmamış',
    'The due date must use the ISO format: YYYY-MM-DD' => 'Tamamlanma tarihi ISO formatını kullanmalı: YYYY-MM-DD',
    'Download CSV template' => 'CSV taslağını indir',
    'No external integration registered.' => 'Hiç dış entegrasyon kaydedilmemiş.',
    'Duplicates are not imported' => 'Çift girişler içeri aktarılmaz',
    'Usernames must be lowercase and unique' => 'Kullanıcı adları küçük harf ve tekil olmalı',
    'Passwords will be encrypted if present' => 'Şifreler (eğer varsa) kriptolanır',
    '%s attached a new file to the task %s' => '%s, %s görevine yeni dosya ekledi',
    'Link type' => 'Bağlantı türü',
    'Assign automatically a category based on a link' => 'Bir bağlantıya göre otomatik olarak kategori ata',
    'BAM - Konvertible Mark' => 'BAM - Konvertible Mark',
    'Assignee Username' => 'Atanan kullanıcı adı',
    'Assignee Name' => 'Atanan İsmi',
    'Groups' => 'Gruplar',
    'Members of %s' => '%s in üyeleri',
    'New group' => 'Yeni grup',
    'Group created successfully.' => 'Grup başarıyla oluşturuldu.',
    'Unable to create your group.' => 'Grup oluşturulamadı.',
    'Edit group' => 'Grubu düzenle',
    'Group updated successfully.' => 'Grup başarıyla güncellendi.',
    'Unable to update your group.' => 'Grup güncellenemedi.',
    'Add group member to "%s"' => '"%s" e grup üyesi ekle',
    'Group member added successfully.' => 'Grup üyesi başarıyla eklendi.',
    'Unable to add group member.' => 'Grup üyesi eklenemedi.',
    'Remove user from group "%s"' => '"%s" grubundan kullanıcı çıkar',
    'User removed successfully from this group.' => 'Kullanıcı bu gruptan başarıyla çıkarıldı.',
    'Unable to remove this user from the group.' => 'Bu kullanıcı bu grubtan çıkarılamadı',
    'Remove group' => 'Grubu sil',
    'Group removed successfully.' => 'Grup başarıyla silindi.',
    'Unable to remove this group.' => 'Grup silinemedi.',
    'Project Permissions' => 'Proje izimleri',
    'Manager' => 'Müdür',
    'Project Manager' => 'Proje müdürü',
    'Project Member' => 'Proje üyesi',
    'Project Viewer' => 'Proje izleyicisi',
    'Your account is locked for %d minutes' => 'Hesabınız %d dakika boyunca kilitlendi',
    'Invalid captcha' => 'Geçersiz captcha',
    'The name must be unique' => 'İsim tekil olmalı',
    'View all groups' => 'Tüm grupları görüntüle',
    'There is no user available.' => 'Uygun üye yok',
    'Do you really want to remove the user "%s" from the group "%s"?' => '"%s" kullanıcısını "%s" grubundan çıkarmak istediğinize emin misiniz?',
    'There is no group.' => 'Hiç grup yok.',
    'Add group member' => 'Grup üyesi ekle',
    'Do you really want to remove this group: "%s"?' => '"%s" grubunu silmek istediğinize emin misiniz?',
    'There is no user in this group.' => 'Bu grupta hiç kullanıcı yok.',
    'Permissions' => 'İzinler',
    'Allowed Users' => 'İzin verilen kullanıcı',
    'No specific user has been allowed.' => 'Hiç bir kullanıcıya özel olarak izin verilmemiş.',
    'Role' => 'Rol',
    'Enter user name...' => 'Kullanıcı adını girin...',
    'Allowed Groups' => 'İzinli gruplar',
    'No group has been allowed.' => 'Hiç bir gruba özel olarak izin verilmemiş',
    'Group' => 'Grup',
    'Group Name' => 'Grup adı',
    'Enter group name...' => 'Grup adını girin...',
    'Role:' => 'Rol:',
    'Project members' => 'Proje üyeleri',
    '%s mentioned you in the task #%d' => '%s sizden #%d görevinde bahsetti',
    '%s mentioned you in a comment on the task #%d' => '%s sizden #%d görevindeki bir yorumda bahsetti',
    'You were mentioned in the task #%d' => '#%d görevinde sizden bahsedildi',
    'You were mentioned in a comment on the task #%d' => '#%d görevindeki bir yorumda sizden bahsedildi',
    'Estimated hours: ' => 'Tahmini saat:',
    'Actual hours: ' => 'Gerçekleşen saat:',
    'Hours Spent' => 'Harcanan saat',
    'Hours Estimated' => 'Tahmini saat',
    'Estimated Time' => 'Tahmini süre',
    'Actual Time' => 'Gerçekleşen süre',
    'Estimated vs actual time' => 'Tahmini vs gerçekleşen süre',
    'RUB - Russian Ruble' => ' RUB - Rus Rublesi',
    'Assign the task to the person who does the action when the column is changed' => 'Sütun değiştirildiği zaman görevi eylemi gerçekleştiren kişiye ata',
    'Close a task in a specific column' => 'Belirli bir sütundaki görevi kapat',
    'Time-based One-time Password Algorithm' => 'Zamana bağlı Tek-Kullanımlık şifre algoritması',
    'Two-Factor Provider: ' => 'Çift-Kademeli doğrulama sağlayıcısı: ',
    'Disable two-factor authentication' => 'Çift-Kademeli doğrulamayı devre dışı bırak',
    'Enable two-factor authentication' => 'Çift-Kademeli doğrulamayı etkinleştir',
    'There is no integration registered at the moment.' => 'Şu anda kayıtlı bir entegrasyon bulunmuyor.',
    'Password Reset for Kanboard' => 'Kanboard için şifre sıfırlama',
    'Forgot password?' => 'Şifrenizi mi unuttunuz?',
    'Enable "Forget Password"' => '"Şifremi unuttum" komutunu etkinleştir',
    'Password Reset' => 'Şifre sıfırlama',
    'New password' => 'Yeni şifre',
    'Change Password' => 'Şifreyi değiştir',
    'To reset your password click on this link:' => 'Şifrenizi sıfırlamak için bu linke tıklayın:',
    'Last Password Reset' => 'Son şifre sıfırlama',
    'The password has never been reinitialized.' => 'Şifre hiç bir zaman tekrar başlatılmamış.',
    'Creation' => 'Oluşturulma',
    'Expiration' => 'Sona erme',
    'Password reset history' => 'Şifre sıfırlama geçmişi',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => '"%s" sütunu ve "%s" kulvarındaki tüm görevler başarıyla kapatıldı.',
    'Do you really want to close all tasks of this column?' => 'Bu sütundaki tüm görevleri kapatmak istediğinize emin misiniz?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '"%s" sütunu ve "%s" kulvarındaki %d görev kapatılacak.',
    'Close all tasks in this column and this swimlane' => 'Bu sütundaki tüm görevleri kapat',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Proje bildirimleri için hiçbir plugin kaydedilmedi. Yine de profil sayfanızdan bildirim ayarları yapabilirsiniz.',
    'My dashboard' => 'Panom',
    'My profile' => 'Profilim',
    'Project owner: ' => 'Proje sahibi: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'Proje kodu opsiyoneldir ve alfanümerik olmalıdır, örneğin: PROJE1',
    'Project owner' => 'Proje sahibi',
    'Personal projects do not have users and groups management.' => '(Kişiye) Özel projelerde kullanıcı ve grup yönetimi yoktur.',
    'There is no project member.' => 'Proje ekibi yok.',
    'Priority' => 'Öncelik',
    'Task priority' => 'Görev önceliği',
    'General' => 'Genel',
    'Dates' => 'Tarihler',
    'Default priority' => 'Varsayılan öncelik',
    'Lowest priority' => 'En düşük öncelik',
    'Highest priority' => 'En yüksek öncelik',
    'Close a task when there is no activity' => 'Bir aktivite olmadığında görevi kapat',
    'Duration in days' => 'Süre (gün olarak)',
    'Send email when there is no activity on a task' => 'Bir görevde aktivite olmadığında e-posta gönder',
    'Unable to fetch link information.' => 'Link eşleştirilemiyor.',
    'Daily background job for tasks' => 'Görevler için günlük otomatik arkaplan işleri',
    'Auto' => 'Otomatik',
    'Related' => 'İlişkili',
    'Attachment' => 'Ek',
    'Web Link' => 'Web Linki',
    'External links' => 'Harici linkler',
    'Add external link' => 'Harici link ekle',
    'Type' => 'Tip',
    'Dependency' => 'Bağımlılık',
    'Add internal link' => 'Dahili link ekle',
    'Add a new external link' => 'Yeni bir harici link ekle',
    'Edit external link' => 'Harici linki düzenle',
    'External link' => 'Harici link',
    'Copy and paste your link here...' => 'Linkinizi kopyalayıp buraya yapıştırın...',
    'URL' => 'URL',
    'Internal links' => 'Dahili linkler',
    'Assign to me' => 'Bana ata',
    'Me' => 'Ben',
    'Do not duplicate anything' => 'Hiçbir projeyi örnek alma',
    'Projects management' => 'Proje yönetimi',
    'Users management' => 'Kullanıcı yönetimi',
    'Groups management' => 'Grup yönetimi',
    'Create from another project' => 'Başka bir projeden oluştur',
    'open' => 'açık',
    'closed' => 'kapalı',
    'Priority:' => 'Öncelik',
    'Reference:' => 'Referans',
    'Complexity:' => 'Zorluk',
    'Swimlane:' => 'Kulvar',
    'Column:' => 'Kolon',
    'Position:' => 'Pozisyon',
    'Creator:' => 'Oluşturan',
    'Time estimated:' => 'Tahmini zaman',
    '%s hours' => '%s saat',
    'Time spent:' => 'Geçen Süre:',
    'Created:' => 'Oluşturuldu',
    'Modified:' => 'Güncellendi',
    'Completed:' => 'Tamamlandı',
    'Started:' => 'Başlatıldı',
    'Moved:' => 'Taşındı',
    'Task #%d' => 'Görev #%d',
    'Time format' => 'Saat formatı',
    'Start date: ' => 'Başlangıç tarihi',
    'End date: ' => 'Bitiş tarihi',
    'New due date: ' => 'Yeni hedef tarih',
    'Start date changed: ' => 'Başlangıç tarihi değişti:',
    'Disable personal projects' => 'Özel projeleri engelle',
    'Do you really want to remove this custom filter: "%s"?' => 'Bu özel filtreyi gerçekten kaldırmak istiyor musunuz: "%s"?',
    'Remove a custom filter' => 'Özel filtre kaldır',
    'User activated successfully.' => 'Kullanıcı başarıyla aktifleştirildi',
    'Unable to enable this user.' => 'Bu kullanıcı etkinleştirilemiyor.',
    'User disabled successfully.' => 'Kullanıcı başarıyla engellendi.',
    'Unable to disable this user.' => 'Bu kullanıcı engellenemez.',
    'All files have been uploaded successfully.' => 'Tüm dosyalar başarıyla yüklendi.',
    'The maximum allowed file size is %sB.' => 'Maksimum dosya büyüklüğü %s B.',
    'Drag and drop your files here' => 'Dosyalarınızı buraya sürükleyip bırakın',
    'choose files' => 'dosyaları seç',
    'View profile' => 'Profili göster',
    'Two Factor' => 'İki faktör',
    'Disable user' => 'Kullanıcıyı engelle',
    'Do you really want to disable this user: "%s"?' => '%s kullanıcısını gerçekten engellemek istiyor musunuz?',
    'Enable user' => 'Kullanıcıyı etkinleştir',
    'Do you really want to enable this user: "%s"?' => '%s kullanıcısını gerçekten etkinleştirmek istiyor musunuz?',
    'Download' => 'İndir',
    'Uploaded: %s' => 'Yükle: %s',
    'Size: %s' => 'Boyut: %s',
    'Uploaded by %s' => '%s tarafından yüklendi',
    'Filename' => 'Dosya adı',
    'Size' => 'Boyutu',
    'Column created successfully.' => 'Kolon başarıyla oluşturuldu.',
    'Another column with the same name exists in the project' => 'Projede aynı isimli başka bir kolon var',
    'Default filters' => 'Varsayılan filtreler',
    'Your board doesn\'t have any columns!' => 'Pano nuzda kolon bulunmuyor!',
    'Change column position' => 'Kolon sıralamasını değiştir',
    'Switch to the project overview' => 'Proje özetine geç',
    'User filters' => 'Kullanıcı filtreleri',
    'Category filters' => 'Kategori filtreleri',
    'Upload a file' => 'Bir dosya yükle',
    'View file' => 'Dosyayı göster',
    'Last activity' => 'Son aktivite',
    'Change subtask position' => 'Alt görev sırasını değiştir',
    'This value must be greater than %d' => 'Bu değer %d den büyük olmalı',
    'Another swimlane with the same name exists in the project' => 'Projede aynı isimli başka bir kulvar var',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Örneğin: https://ornek.kanboard.org/ (sabit URLler oluşturmak için)',
    'Actions duplicated successfully.' => 'İşlemler başarıyla çoklandı.',
    'Unable to duplicate actions.' => 'İşlemler çoklanamıyor.',
    'Add a new action' => 'Yeni bir işlem ekle',
    'Import from another project' => 'Başka bir projeden aktar',
    'There is no action at the moment.' => 'Şu anda bir işlem yok',
    'Import actions from another project' => 'Başka bir projeden işlemleri aktar',
    'There is no available project.' => 'Uygun bir proje yok.',
    'Local File' => 'Yerel dosya',
    'Configuration' => 'Konfigürasyon',
    'PHP version:' => 'PHP versiyonu:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => 'OS versiyonu:',
    'Database version:' => 'Veritabanı versiyonu:',
    'Browser:' => 'Tarayıcı:',
    'Task view' => 'Görev görünümü',
    'Edit task' => 'Görev güncelle',
    'Edit description' => 'Açıklamayı güncelle',
    'New internal link' => 'Yeni iç link',
    'Display list of keyboard shortcuts' => 'Kısayol tuşları listesini göster',
    'Avatar' => 'Simge',
    'Upload my avatar image' => 'Avatar resmimi yükle',
    'Remove my image' => 'Resmimi kaldır',
    'The OAuth2 state parameter is invalid' => 'OAuth2 durum parametresi geçersiz',
    'User not found.' => 'Kullanıcı bulunamadı',
    'Search in activity stream' => 'Aktivite akışında ara',
    'My activities' => 'Aktivitelerim',
    'Activity until yesterday' => 'Düne kadar olan aktiviteler',
    'Activity until today' => 'Bugüne kadar olan aktiviteler',
    'Search by creator: ' => 'Oluşturan ile ara',
    'Search by creation date: ' => 'Oluşturma tarihi ile ara',
    'Search by task status: ' => 'Görev durumu ile ara',
    'Search by task title: ' => 'Görev başlığı ile ara',
    'Activity stream search' => 'Aktivite akışı araması',
    'Projects where "%s" is manager' => '%s in müdürü olduğu projeler',
    'Projects where "%s" is member' => '%s in ekip üyesi olduğu projeler',
    'Open tasks assigned to "%s"' => '%s e atanan görevleri aç',
    'Closed tasks assigned to "%s"' => '%s e atanan görevleri kapat',
    'Assign automatically a color based on a priority' => 'Önceliğe bağlı olarak bir renk belirle',
    'Overdue tasks for the project(s) "%s"' => '%s proje(leri) için süresi geçen görevler',
    'Upload files' => 'Dosyaları yükle',
    'Installed Plugins' => 'Yüklenmiş Eklentiler',
    'Plugin Directory' => 'Eklenti Klasörü',
    'Plugin installed successfully.' => 'Eklenti başarıyla kuruldu.',
    'Plugin updated successfully.' => 'Eklenti başarıyla güncellendi.',
    'Plugin removed successfully.' => 'Eklenti başarıyla kaldırıldı.',
    'Subtask converted to task successfully.' => 'Alt görev başarıyla göreve dönüştürüldü.',
    'Unable to convert the subtask.' => 'Alt görev dönüştürülemedi',
    'Unable to extract plugin archive.' => 'Plugin (sıkıştırılmış) dosyası açılamadı.',
    'Plugin not found.' => 'Eklenti bulunamadı',
    'You don\'t have the permission to remove this plugin.' => 'Bu plugin\'i kaldırmak için yetkiniz yok.',
    'Unable to download plugin archive.' => 'Eklenti dosyası indirilemedi.',
    'Unable to write temporary file for plugin.' => 'Eklenti için geçici dosya oluşturulamadı.',
    'Unable to open plugin archive.' => 'Eklenti dosyası açılamadı.',
    'There is no file in the plugin archive.' => 'Eklenti (sıkıştırılmış) dosyasında, dosya bulunmuyor.',
    'Create tasks in bulk' => 'Toplu olarak görev oluştur',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Kanbord sisteminiz arayüzden eklenti kurulacak şekilde ayarlanmamış.',
    'There is no plugin available.' => 'Uygun eklenti yok.',
    'Install' => 'Kur',
    'Update' => 'Güncelle',
    'Up to date' => 'Güncel',
    'Not available' => 'Uygun değil',
    'Remove plugin' => 'Eklentiyi kaldır',
    'Do you really want to remove this plugin: "%s"?' => '"%s" eklentiyi gerçekten kaldırmak istiyor musunuz?',
    'Uninstall' => 'Kaldır',
    'Listing' => 'Listeliyor',
    'Metadata' => 'Meta veri',
    'Manage projects' => 'Projeler',
    'Convert to task' => 'Göreve dönüştür',
    'Convert sub-task to task' => 'Alt görevi göreve dönüştür',
    'Do you really want to convert this sub-task to a task?' => 'Bu alt görevi, göreve dönüştüreceğinize emin misiniz?',
    'My task title' => 'Görev başlığım',
    'Enter one task by line.' => 'Görevleri satır satır girin',
    'Number of failed login:' => 'Başarısız login denemesi sayısı',
    'Account locked until:' => 'Hesap şu zamana kadar kilitlendi:',
    'Email settings' => 'E-posta ayarları',
    'Email sender address' => 'E-posta gönderen adresi',
    'Email transport' => 'E-posta taşıma',
    'Webhook token' => 'Web kancası anahtarı',
    'Project tags management' => 'Proje etiket yönetimi',
    'Tag created successfully.' => 'Etiket başarıyla oluturuldu.',
    'Unable to create this tag.' => 'Etiket oluşturulamıyor.',
    'Tag updated successfully.' => 'Etiket başarıyla güncellendi.',
    'Unable to update this tag.' => 'Etiket güncellenemedi.',
    'Tag removed successfully.' => 'Etiket başarıyla kaldırıldı.',
    'Unable to remove this tag.' => 'Etiket kaldırılamadı.',
    'Global tags management' => 'Genel etiket yönetimi',
    'Tags' => 'Etiketler',
    'Tags management' => 'Etiket yönetimi',
    'Add new tag' => 'Yeni etiket ekle',
    'Edit a tag' => 'Etiket güncelle',
    'Project tags' => 'Proje etiketleri',
    'There is no specific tag for this project at the moment.' => 'Proje için şu anda bir etiket bulunmuyor.',
    'Tag' => 'Etiket',
    'Remove a tag' => 'Etiket kaldır',
    'Do you really want to remove this tag: "%s"?' => '"%s" etiketini kaldıracağınıza emin misiniz?',
    'Global tags' => 'Genel etiketler',
    'There is no global tag at the moment.' => 'Şu anda genel bir etiket bulunmuyor.',
    'This field cannot be empty' => 'Bu alan boş bırakılamaz',
    'Close a task when there is no activity in a specific column' => 'Bir kolonda hareket olmadığında bir görevi kapat',
    '%s removed a subtask for the task #%d' => '%d görevi için %s bir alt görevi kaldırdı',
    '%s removed a comment on the task #%d' => '%s %d görevi için bir yorumu kaldırdı',
    'Comment removed on task #%d' => '%d görevindeki yorum kaldırıldı',
    'Subtask removed on task #%d' => '%d görevindeki alt görev kaldırıldı',
    'Hide tasks in this column in the dashboard' => 'Panoda bu kolondaki görevleri gizle',
    '%s removed a comment on the task %s' => '%s %s görevinde bir yorumu kaldırdı',
    '%s removed a subtask for the task %s' => '%s %s alt görevini kaldırdı',
    'Comment removed' => 'Yorum kaldırıldı',
    'Subtask removed' => 'Alt görev kaldırıldı',
    '%s set a new internal link for the task #%d' => '%d görevi için %s bir iç link oluşturdu',
    '%s removed an internal link for the task #%d' => '%d görevi için %s bir iç linki kaldırdı',
    'A new internal link for the task #%d has been defined' => '%d görevi için yeni bir iç link tanımlandı',
    'Internal link removed for the task #%d' => '%d görevi için iç link kaldırıldı',
    '%s set a new internal link for the task %s' => '%s görevi için %s yeni bir iç link oluşturdu',
    '%s removed an internal link for the task %s' => '%s %s görevi için bir iç linki kaldırdı',
    'Automatically set the due date on task creation' => 'Görev oluştururken hedef tarihi otomatik ata',
    'Move the task to another column when closed' => 'Görev kapandığında başka bir kolona taşı',
    'Move the task to another column when not moved during a given period' => 'Bir kolonda belirli bir süre hareketsiz kalırsa görevi başka bir kolona taşı',
    'Dashboard for %s' => '%s için Pano',
    'Tasks overview for %s' => '%s için görev özeti',
    'Subtasks overview for %s' => '%s için alt görev özeti',
    'Projects overview for %s' => '%s için proje özeti',
    'Activity stream for %s' => '%s için akış',
    'Assign a color when the task is moved to a specific swimlane' => 'Görev bir kulvara taşındığında rengini değiştir',
    'Assign a priority when the task is moved to a specific swimlane' => 'Görev bir kulvara taşındığında önceliğini değiştir',
    'User unlocked successfully.' => 'Kullanıcı kilidi başarıyla kaldırıldı.',
    'Unable to unlock the user.' => 'Kullanıcı kilitlenemiyor.',
    'Move a task to another swimlane' => 'Görevi başka bir kulvara taşı',
    'Creator Name' => 'Oluşturan Adı',
    'Time spent and estimated' => 'Tahmini ve geçen süre',
    'Move position' => 'Taşıma sırası',
    'Move task to another position on the board' => 'Görevin sırasını değiştir',
    'Insert before this task' => 'Bu görevin öncesine oluştur',
    'Insert after this task' => 'Bu görevin ardına oluştur',
    'Unlock this user' => 'Bu kullanıcının kilidini kaldır',
    'Custom Project Roles' => 'Ek Proje Rolleri',
    'Add a new custom role' => 'Proje rolü ekle',
    'Restrictions for the role "%s"' => '"%s" rolü için kısıtlamalar',
    'Add a new project restriction' => 'Yeni kısıtlama ekle',
    'Add a new drag and drop restriction' => 'Sürükle bırak kısıtlaması ekle',
    'Add a new column restriction' => 'Kolon kısıtlaması ekle',
    'Edit this role' => 'Rolü güncelle',
    'Remove this role' => 'Rolü kaldır',
    'There is no restriction for this role.' => 'Bu rol için bir kısıtlama yok',
    'Only moving task between those columns is permitted' => 'Sadece belirlenen kolonlar arasında taşıma mümkündür',
    'Close a task in a specific column when not moved during a given period' => 'Bir kolonda belirli bir süre hareketsiz kalan görev kapatılsın',
    'Edit columns' => 'Kolonları güncelle',
    'The column restriction has been created successfully.' => 'Kolon kısıtlaması başarıyla oluşturuldu.',
    'Unable to create this column restriction.' => 'Kolon kısıtlaması oluşturulamadı.',
    'Column restriction removed successfully.' => 'Kolon kısıtlaması başarıyla kaldırıldı.',
    'Unable to remove this restriction.' => 'Bu kısıtlama kaldırılamıyor.',
    'Your custom project role has been created successfully.' => 'Ek proje rolü başarıyla oluşturuldu.',
    'Unable to create custom project role.' => 'Ek proje rolü oluşturulamadı',
    'Your custom project role has been updated successfully.' => 'Ek proje rolü başarıyla güncellendi.',
    'Unable to update custom project role.' => 'Ek proje rolü güncellenemiyor.',
    'Custom project role removed successfully.' => 'Ek proje rolü başarıyla kaldırıldı.',
    'Unable to remove this project role.' => 'Proje rolü kaldırılamıyor.',
    'The project restriction has been created successfully.' => 'Proje kısıtlaması başarıyla oluşturuldu.',
    'Unable to create this project restriction.' => 'Proje kısıtlaması oluşturulamadı',
    'Project restriction removed successfully.' => 'Proje kısıtlaması başarıyla kaldırıldı.',
    'You cannot create tasks in this column.' => 'Bu kolonda görev oluşturamazsınız.',
    'Task creation is permitted for this column' => 'Bu kolonda görev oluşturulabilir.',
    'Closing or opening a task is permitted for this column' => 'Bu kolonda görev açma yahut kapatma yapılabilir.',
    'Task creation is blocked for this column' => 'Bu kolonda görev oluşturma bloke edilmiştir.',
    'Closing or opening a task is blocked for this column' => 'Bu kolonda görev açma yahut kapatma bloke edilmiştir.',
    'Task creation is not permitted' => 'Görev oluşturmaya izin verilmemiştir',
    'Closing or opening a task is not permitted' => 'Görev açmaya yahut kapatmaya izin verilmemiştir',
    'New drag and drop restriction for the role "%s"' => '"%s" rolü için yeni sürükle bırak kısıtlaması',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Bu roldeki kullanıcılar sadece kaynak ve hedef kolonlar arasında görevi hareket ettirebilir.',
    'Remove a column restriction' => 'Kolon kısıtlamasını kaldır',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Kolon kısıtlamasının "%s" den "%s" e değiştireceğinize emin misiniz?',
    'New column restriction for the role "%s"' => '"%s" rolü için yeni kolon kısıtlaması',
    'Rule' => 'Kural',
    'Do you really want to remove this column restriction?' => 'Kolon kısıtlamasını kaldırmak istediğinize emin misiniz?',
    'Custom roles' => 'Ek roller',
    'New custom project role' => 'Yeni ek proje rolü',
    'Edit custom project role' => 'Ek proje rolünü güncelle',
    'Remove a custom role' => 'Ek rolü kaldır',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => '"%s" ek rolünü kaldıracağınıza emin misiniz? Bu role ait tüm kullanıcılar proje kullanıcısı olacak.',
    'There is no custom role for this project.' => 'Bu proje için ek rol bulunmuyor.',
    'New project restriction for the role "%s"' => '"%s" rolü için yeni proje kısıtlaması',
    'Restriction' => 'Kısıtlama',
    'Remove a project restriction' => 'Proje kısıtlaması kaldır',
    'Do you really want to remove this project restriction: "%s"?' => '"%s" proje kısıtlamasını kaldırmak istediğinize emin misiniz?',
    'Duplicate to multiple projects' => 'Birden çok projeye çokla',
    'This field is required' => 'Bu alan gerekli',
    'Moving a task is not permitted' => 'Görev taşımaya izin verilmemiş',
    'This value must be in the range %d to %d' => 'Bu değer şu aralıkta olmalı: "%d" "%d"',
    'You are not allowed to move this task.' => 'Bu görevi taşımaya izniniz yok.',
    'API User Access' => 'API Kullanıcı Erişimi',
    'Preview' => 'Öngörünüm',
    'Write' => 'Yaz',
    'Write your text in Markdown' => 'Metninizi Markdown a yazın',
    'No personal API access token registered.' => 'Kişisel API erişim anahtarınız kaydedilmedi.',
    'Your personal API access token is "%s"' => 'Kişisel API erişim anahtarınız "%s"',
    'Remove your token' => 'Anahtarı kaldır',
    'Generate a new token' => 'Yeni bir anahtar oluştur',
    'Showing %d-%d of %d' => 'Gösterilen %d-%d / %d',
    'Outgoing Emails' => 'Gönderilen ePostalar',
    'Add or change currency rate' => 'Kur Oranını ekle veya değiştir',
    'Reference currency: %s' => 'Referans parabirimi: %s',
    'Add custom filters' => 'Özel filtre ekle',
    'Export' => 'Dışa aktar',
    'Add link label' => 'Bağlantı etiketi ekle',
    'Incompatible Plugins' => 'Uyumsuz Eklentiler',
    'Compatibility' => 'Uyumluluk',
    'Permissions and ownership' => 'İzinler ve sahiplik',
    'Priorities' => 'Öncelikler',
    'Close this window' => 'Bu pencereyi kapat',
    'Unable to upload this file.' => 'Bu dosya yüklenemiyor',
    'Import tasks' => 'Görevleri içeri aktar',
    'Choose a project' => 'Proje seçin',
    'Profile' => 'Profil',
    'Application role' => 'Uygulama rolü',
    '%d invitations were sent.' => '%d Davetiye gönderildi',
    '%d invitation was sent.' => '%d Davetiye gönderildi',
    'Unable to create this user.' => 'Bu kullanıcı oluşturulamadı.',
    'Kanboard Invitation' => 'Kanboard Daveti',
    'Visible on dashboard' => 'Panoda görünür',
    'Created at:' => 'Oluşturulma: ',
    'Updated at:' => 'Güncellenme: ',
    'There is no custom filter.' => 'Uygulanmış özel filtre yok',
    'New User' => 'Yeni Kullanıcı',
    'Authentication' => 'Yetkilendirme',
    'If checked, this user will use a third-party system for authentication.' => 'İşaretlenirse, bu kullanıcı kimlik doğrulama için üçüncü parti bir sistem kullanacaktır.',
    'The password is necessary only for local users.' => 'Parola yalnızca yerel kullanıcılar için gereklidir',
    'You have been invited to register on Kanboard.' => 'Kanboarda kayıt yaptırmak için davet edildiniz.',
    'Click here to join your team' => 'Takımınıza katılmak için buraya tıklayın',
    'Invite people' => 'İnsanları davet et',
    'Emails' => 'ePostalar',
    'Enter one email address by line.' => 'Her satıra bir adet email girin.',
    'Add these people to this project' => 'Kişileri bu projeye ekle',
    'Add this person to this project' => 'Kişiyi bu projeye ekle',
    'Sign-up' => 'Kayıt',
    'Credentials' => 'Kimlik bilgileri',
    'New user' => 'Yeni kullanıcı',
    'This username is already taken' => 'Bu kullanıcı adı zaten alınmış',
    'Your profile must have a valid email address.' => 'Profiliniz için geçerli bir ePosta adresi gerekiyor.',
    'TRL - Turkish Lira' => 'TRL - Türk Lirası',
    'The project email is optional and could be used by several plugins.' => 'Proje ePostası isteğe bağlıdır ve eklentiler tarafından kullanılabilir',
    'The project email must be unique across all projects' => 'Proje e-postası tüm projelerde benzersiz olmalıdır.',
    'The email configuration has been disabled by the administrator.' => 'ePosta ayarları yönetici tarafından devre dışı bırakılmış.',
    'Close this project' => 'Bu projeyi kapat',
    'Open this project' => 'Bu projeyi aç',
    'Close a project' => 'Proje kapat',
    'Do you really want to close this project: "%s"?' => 'Bu projeyi kapatmak istediğinize emin misiniz? : "%s"',
    'Reopen a project' => 'Projeyi tekrar aç',
    'Do you really want to reopen this project: "%s"?' => 'Bu projeyi tekrar açmak istediğinizi onaylıyor musunuz? : "%s"',
    'This project is open' => 'Bu proje açıktır',
    'This project is closed' => 'Bu proje kapatılmış',
    'Unable to upload files, check the permissions of your data folder.' => 'Dosya yüklenemedi. Lütfen yükleme dizine yazma izninizi kontrol ediniz.',
    'Another category with the same name exists in this project' => 'Bu projede aynı ada sahip başka bir kategori var',
    'Comment sent by email successfully.' => 'Yorum ePosta ile başarıyla gönderildi.',
    'Sent by email to "%s" (%s)' => 'ePostayı gönder "%s" (%s)',
    'Unable to read uploaded file.' => 'Yüklenen dosya okunamadı.',
    'Database uploaded successfully.' => 'Veritabanı başarıyla yüklendi.',
    'Task sent by email successfully.' => 'Görev ePosta ile başarıyla gönderildi.',
    'There is no category in this project.' => 'Bu projenin kategorisi yok',
    'Send by email' => 'ePosta ile gönder',
    'Create and send a comment by email' => 'Yorum oluştur ve ePosta ile gönder',
    'Subject' => 'Konu',
    'Upload the database' => 'Veritabanına yükle',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Daha önce indirdiğiniz Sqlite Veritabanı dosyasını yükleyebilirsiniz (Gzip formatında)',
    'Database file' => 'Veritabanı dosyası',
    'Upload' => 'Yükle',
    'Your project must have at least one active swimlane.' => 'Projenizin en az bir aktif kulvara sahip olması gerekir',
    'Project: %s' => 'Proje: %s',
    'Automatic action not found: "%s"' => 'Otomatik işlem bulunamadı: "%s"',
    '%d projects' => '%d proje',
    '%d project' => '%d proje',
    'There is no project.' => 'Proje yok.',
    'Sort' => 'Sırala',
    'Project ID' => 'Proje No',
    'Project name' => 'Proje Adı',
    'Public' => 'Herkese açık',
    'Personal' => 'Gizli',
    '%d tasks' => '%d görev',
    '%d task' => '%d görev',
    'Task ID' => 'Görev No',
    'Assign automatically a color when due date is expired' => 'Son günü geçtiğinde otomatik olarak bir renk ata',
    'Total score in this column across all swimlanes' => 'Tüm kulvarlara göre bu kulvarın toplam puanı',
    'HRK - Kuna' => 'HRK - Kuna',
    'ARS - Argentine Peso' => 'ARS - Arjantin Pezosu',
    'COP - Colombian Peso' => 'COP - Kolombiya Pezosu',
    '%d groups' => '%d grup',
    '%d group' => '%d grup',
    'Group ID' => 'Grup No',
    'External ID' => 'Harici No',
    '%d users' => '%d kullanıcı',
    '%d user' => '%d kullanıcı',
    'Hide subtasks' => 'Alt görevleri gizler',
    'Show subtasks' => 'Alt görevleri göster',
    'Authentication Parameters' => 'Yetkilendirme Parametreleri',
    'API Access' => 'API Erişimi',
    'No users found.' => 'Kullanıcı yok',
    'User ID' => 'Kullanıcı No',
    'Notifications are activated' => 'Bildirimler etkinleştirildi',
    'Notifications are disabled' => 'Bildirimler devre dışı',
    'User disabled' => 'Kullanıcı devre dışı',
    '%d notifications' => '%d bildirim',
    '%d notification' => '%d bildirim',
    'There is no external integration installed.' => 'Yüklenmiş harici entegrasyon yok.',
    'You are not allowed to update tasks assigned to someone else.' => 'Başkasına atanmış görevi güncelleme izniniz yok.',
    'You are not allowed to change the assignee.' => 'Atanmış kişiyi değiştirme yetkiniz yok.',
    'Task suppression is not permitted' => 'Görev silmeye izniniz yok',
    'Changing assignee is not permitted' => 'Atanmışı değiştirme izniniz yok',
    'Update only assigned tasks is permitted' => 'Yalnızca atandığınız görevleri güncelleyebilirsiniz',
    'Only for tasks assigned to the current user' => 'Yalnızca geçerli kullanıcıya atanan görevler için',
    'My projects' => 'Projelerim',
    'You are not a member of any project.' => 'Herhangi bir projenin üyesi değilsiniz.',
    'My subtasks' => 'Altgörevlerim',
    '%d subtasks' => '%d alt görev',
    '%d subtask' => '%d alt görev',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Geçerli kullanıcıya atanan görevler için yalnızca o sütunlar arasında hareket eden bir göreve izin verilir.',
    '[DUPLICATE]' => '[ÇİFT]',
    'DKK - Danish Krona' => 'DKK - Danimarka Kronu',
    'Remove user from group' => 'Kullanıcıyı gruptan çıkar',
    'Assign the task to its creator' => 'Oluşturucusuna görev ata',
    'This task was sent by email to "%s" with subject "%s".' => 'Bu görev "%s" konusuyla "%s" ePosta adresine gönderildi.',
    'Predefined Email Subjects' => 'Öntanımlı ePosta konuları',
    'Write one subject by line.' => 'Her satıra bir konu yazınız',
    'Create another link' => 'Başka bağlantı oluştur',
    'BRL - Brazilian Real' => 'BRL - Brezilya Reali',
    'Add a new Kanboard task' => 'Yeni bir Kanboard Görevi ekle',
    'Subtask not started' => 'Alt Görev başlatılmamış',
    'Subtask currently in progress' => 'Alt Görev işlemde',
    'Subtask completed' => 'Alt Görev tamamlandı',
    'Subtask added successfully.' => 'Alt Görev başarıyla eklendi.',
    '%d subtasks added successfully.' => '%d Alt Görev başarıyla eklendi.',
    'Enter one subtask by line.' => 'Her satıra bir alt görev giriniz.',
    'Predefined Contents' => 'Ön tanımlı İçerik',
    'Predefined contents' => 'Ön tanımlı içerik',
    'Predefined Task Description' => 'Ön tanımlı Görev Açıklaması',
    'Do you really want to remove this template? "%s"' => 'Bu şablonu kaldırmayı gerçekten istiyor musunuz? "%s"',
    'Add predefined task description' => 'Ön tanımlı görev açıklaması ekle',
    'Predefined Task Descriptions' => 'Ön Tanımlı Görev Açıklamaları',
    'Template created successfully.' => 'Şablon başarıyla oluşturuldu.',
    'Unable to create this template.' => 'Şablon oluşturulamadı.',
    'Template updated successfully.' => 'Şablon başarıyla güncellendi.',
    'Unable to update this template.' => 'Şablon güncellenemedi.',
    'Template removed successfully.' => 'Şablon başarıyla kaldırıldı.',
    'Unable to remove this template.' => 'Şablon kaldırılamıyor.',
    'Template for the task description' => 'Görev Açıklaması için Şablon',
    'The start date is greater than the end date' => 'Başlama Tarihi Bitiş Tarihinden büyük',
    'Tags must be separated by a comma' => 'Etiketler virgül ile ayrılmalı',
    'Only the task title is required' => 'Sadece görev başlığı gereklidir',
    'Creator Username' => 'Oluşturan Kullanıcı',
    'Color Name' => 'Renk Adı',
    'Column Name' => 'Kolon Adı',
    'Swimlane Name' => 'Kulvar Adı',
    'Time Estimated' => 'Tahmini Zaman',
    'Time Spent' => 'Harcanan Zaman',
    'External Link' => 'Harici Bağlantı',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Bu özellik iCal beslemesini, RSS beslemesini ve genel pano görünümünü aktifleştirir.',
    'Stop the timer of all subtasks when moving a task to another column' => 'Görev başka bir kolona taşındığında, tüm alt görevlerin zaman sayaçlarını durdur.',
    'Subtask Title' => 'Alt Görev Başlığı',
    'Add a subtask and activate the timer when moving a task to another column' => 'Görev başka bir kolona taşındığında, bir alt görev ekle ve zaman sayacını başlat',
    'days' => 'gün',
    'minutes' => 'dakika',
    'seconds' => 'saniye',
    'Assign automatically a color when preset start date is reached' => 'Başlangıç Tarihi geldiğinde, otomatik olarak bir renk ata',
    'Move the task to another column once a predefined start date is reached' => 'Başlangıç Tarihi geldiğinde, görevi başka bir kolona taşı',
    'This task is now linked to the task %s with the relation "%s"' => 'Bu görev %s görevine bağlandı, ilişki %s',
    'The link with the relation "%s" to the task %s has been removed' => '%s görevindeki %s bağlantısı kaldırıldı',
    'Custom Filter:' => 'Özel Filtre',
    'Unable to find this group.' => 'Bu grup bulunamıyor',
    '%s moved the task #%d to the column "%s"' => '%s , #%d görevini "%s" kolonuna taşıdı',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s , #%d görevini "%s" kolonundaki %d pozisyonuna taşıdı',
    '%s moved the task #%d to the swimlane "%s"' => '%s , #%d görevini "%s" kulvarına taşıdı',
    '%sh spent' => '%sh harcandı',
    '%sh estimated' => '%sh tahmin edildi',
    'Select All' => 'Tümünü Seç',
    'Unselect All' => 'Tüm Seçimi Kaldır',
    'Apply action' => 'Komutu Uygula',
    'Move selected tasks to another column or swimlane' => 'Seçili görevleri başka kolona taşı',
    'Edit tasks in bulk' => 'Görevleri toplu olarak güncelle',
    'Choose the properties that you would like to change for the selected tasks.' => 'Seçili görevler için değiştirilecek özellikleri seç',
    'Configure this project' => 'Proje Ayarları',
    'Start now' => 'Şimdi başla',
    '%s removed a file from the task #%d' => '%s %d görevinden bir dosya çıkardı',
    'Attachment removed from task #%d: %s' => '%s görevinden bir ek dosya çıkarıldı: %d',
    'No color' => 'Renksiz',
    'Attachment removed "%s"' => 'Ek dosya kaldırıldız"%s"',
    '%s removed a file from the task %s' => '%s %s görevinden bir dosya çıkardı',
    'Move the task to another swimlane when assigned to a user' => 'Görev birine atandığında bir kulvara taşı',
    'Destination swimlane' => 'Hedef Kulvar',
    'Assign a category when the task is moved to a specific swimlane' => 'Görev bir kulvara taşındığında bir kategori ata',
    'Move the task to another swimlane when the category is changed' => 'Katgorisi değiştiğinde görevi başka bir kulvara taşı',
    'Reorder this column by priority (ASC)' => 'Kolonu artan önceliğe göre sırala',
    'Reorder this column by priority (DESC)' => 'Kolonu azalan önceliğe göre sırala',
    'Reorder this column by assignee and priority (ASC)' => 'Kolonu atanan ve önceliğe göre artan sırala',
    'Reorder this column by assignee and priority (DESC)' => 'Kolonu atanan ve önceliğe göre azalan sırala',
    'Reorder this column by assignee (A-Z)' => 'Kolonu atanana göre artan sırala (A-Z)',
    'Reorder this column by assignee (Z-A)' => 'Kolonu atanana göre azalan sırala (Z-A)',
    'Reorder this column by due date (ASC)' => 'Kolonu hedef tarihe göre artan sırala',
    'Reorder this column by due date (DESC)' => 'Kolonu hedef tarihe göre azalan sırala',
    'Reorder this column by id (ASC)' => 'Kolonu id ye göre artan sırala',
    'Reorder this column by id (DESC)' => 'Kolonu id ye göre azalan sırala',
    '%s moved the task #%d "%s" to the project "%s"' => '%s görevi taşıdı #%d "%s" "%s" projesine',
    'Task #%d "%s" has been moved to the project "%s"' => 'Görev #%d "%s" tarafından "%s" projesine taşındı',
    'Move the task to another column when the due date is less than a certain number of days' => 'Hedef tarihe belirli bir gün sayısından az kaldığında görevi başka kolona taşı',
    'Automatically update the start date when the task is moved away from a specific column' => 'Görev bir kolondan taşındığında başlangıç tarihini otomatik olarak güncelle',
    'HTTP Client:' => 'HTTP İstemci',
    'Assigned' => 'Atanmış',
    'Task limits apply to each swimlane individually' => 'Görev limitini her kulvara ayrı uygula',
    'Column task limits apply to each swimlane individually' => 'Kolon görev limitleri her kulvara ayrı uygulansın',
    'Column task limits are applied to each swimlane individually' => 'Kolon görev limitleri her kulvara ayrı uygulandı',
    'Column task limits are applied across swimlanes' => 'Kolon görev limitleri tüm kulvarlara uygulandı',
    'Task limit: ' => 'Görev limiti',
    'Change to global tag' => 'Global etikete değiştir',
    'Do you really want to make the tag "%s" global?' => '"%s" etiketini global yapmak istediğinize emin misiniz?',
    'Enable global tags for this project' => 'Bu iş grubu için global etiketleri etkinleştir',
    'Group membership(s):' => 'Grup üyelikleri',
    '%s is a member of the following group(s): %s' => '"%s" şu grupların üyesidir:"%s"',
    '%d/%d group(s) shown' => '%d/%dgrupları göster',
    'Subtask creation or modification' => 'Alt görev oluşturma veya değiştirme',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Görev belirli bir kulvara taşındığında belirli bir kullanıcıya ata',
    'Comment' => 'Yorum',
    'Collapse vertically' => 'Dikey olarak daralt',
    'Expand vertically' => 'Dikey olarak genişlet',
    'MXN - Mexican Peso' => 'MXN - Meksika Pesosu',
    'Estimated vs actual time per column' => 'Sütun başına tahmini ve gerçek zaman',
    'HUF - Hungarian Forint' => 'HUF - Macar Forinti',
    'XBT - Bitcoin' => 'XBT - Bitcoin',
    'You must select a file to upload as your avatar!' => 'Avatarınız olarak yüklemek için bir dosya seçmelisiniz!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Yüklediğiniz dosya geçerli bir resim değil! (Yalnızca *.gif, *.jpg, *.jpeg ve *.png dosyalarına izin verilir!)',
    'Automatically set the due date when the task is moved away from a specific column' => 'Görev belirli bir sütundan taşındığında son tarihi otomatik olarak ayarla',
    'No other projects found.' => 'Başka proje bulunamadı.',
    'Tasks copied successfully.' => 'Görevler başarıyla kopyalandı.',
    'Unable to copy tasks.' => 'Görevler kopyalanamıyor.',
    'Theme' => 'Tema',
    'Theme:' => 'Tema:',
    'Light theme' => 'Açık tema',
    'Dark theme' => 'Koyu tema',
    'Automatic theme - Sync with system' => 'Otomatik tema - Sistemle senkronize et',
    'Application managers or more' => 'Uygulama yöneticileri veya daha fazlası',
    'Administrators' => 'Yöneticiler',
    'Visibility:' => 'Görünürlük:',
    'Standard users' => 'Standart kullanıcılar',
    'Visibility is required' => 'Görünürlük gereklidir',
    'The visibility should be an app role' => 'Görünürlük bir uygulama rolü olmalıdır',
    'Reply' => 'Yanıtla',
    '%s wrote: ' => '%s yazdı: ',
    'Number of visible tasks in this column and swimlane' => 'Bu sütun ve yüzme yolunda görünen görev sayısı',
    'Number of tasks in this swimlane' => 'Bu yüzme yolundaki görev sayısı',
    'Unable to find another subtask in progress, you can close this window.' => 'Devam eden başka bir alt görev bulunamadı, bu pencereyi kapatabilirsiniz.',
    'This theme is invalid' => 'Bu tema geçersiz',
    'This role is invalid' => 'Bu rol geçersiz',
    'This timezone is invalid' => 'Bu saat dilimi geçersiz',
    'This language is invalid' => 'Bu dil geçersiz',
    'This URL is invalid' => 'Bu URL geçersiz',
    'Date format invalid' => 'Tarih biçimi geçersiz',
    'Time format invalid' => 'Saat biçimi geçersiz',
    'Invalid Mail transport' => 'Geçersiz posta aktarımı',
    'Color invalid' => 'Geçersiz renk',
    'This value must be greater or equal to %d' => 'Bu değer %d veya daha büyük olmalıdır',
    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Dosyanın başına BOM ekle (Microsoft Excel için gereklidir)',
    'Just add these tag(s)' => 'Sadece bu etiketleri ekle',
    'Remove internal link(s)' => 'Dahili bağlantıları kaldır',
    'Import tasks from another project' => 'Başka bir projeden görevleri içe aktar',
    'Select the project to copy tasks from' => 'Görevleri kopyalamak için projeyi seçin',
    'The total maximum allowed attachments size is %sB.' => 'Ekler için izin verilen toplam maksimum boyut %sB.',
    'Add attachments' => 'Ekleri ekle',
    'Task #%d "%s" is overdue' => 'Görev #%d "%s" son tarihi geçti',
    'Enable notifications by default for all new users' => 'Tüm yeni kullanıcılar için bildirimleri varsayılan olarak etkinleştir',
    'Assign the task to its creator for specific columns if no assignee is set manually' => 'Sorumlu elle ayarlanmadıysa, belirli sütunlar için görevi oluşturan kişiye ata',
    'Assign a task to the logged user on column change to specified column if no user is assigned' => 'Hiç kullanıcı atanmadıysa, sütun değişikliğinde görev belirtilen sütuna taşındığında görevi oturum açmış kullanıcıya ata',
];
